@@ -17,7 +17,7 @@ mod tests {
     use crate::vec::Vec;
 
     #[test]
-    fn test_as_ref_vec() {
+    fn test_as_ref() {
         let stdvec = vec![2, 1, 3];
         let cratevec = Vec::from(vec![2, 1, 3]);
 
